@@ -30,7 +30,11 @@
 #include "zend_exceptions.h"
 
 #ifdef PHP_WIN32
-# include "win32/php_stdint.h"
+# if PHP_VERSION_ID >= 80000
+#  include "main/php_stdint.h"
+# else
+#  include "win32/php_stdint.h"
+# endif
 # include "win32/signal.h"
 #else
 # include <signal.h>
@@ -68,20 +72,20 @@ static PHP_METHOD(amqp_queue_class, __construct)
 	zval *channelObj;
 	amqp_channel_resource *channel_resource;
 
-	if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "o", &channelObj) == FAILURE) {
+	if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "O", &channelObj, amqp_channel_class_entry) == FAILURE) {
 		return;
 	}
 
 	PHP5to7_MAYBE_INIT(arguments);
 	PHP5to7_ARRAY_INIT(arguments);
-	zend_update_property(this_ce, getThis(), ZEND_STRL("arguments"), PHP5to7_MAYBE_PTR(arguments) TSRMLS_CC);
+	zend_update_property(this_ce, PHP5to8_OBJ_PROP(getThis()), ZEND_STRL("arguments"), PHP5to7_MAYBE_PTR(arguments) TSRMLS_CC);
 	PHP5to7_MAYBE_DESTROY(arguments);
 
 	channel_resource = PHP_AMQP_GET_CHANNEL_RESOURCE(channelObj);
 	PHP_AMQP_VERIFY_CHANNEL_RESOURCE(channel_resource, "Could not create queue.");
 
-	zend_update_property(this_ce, getThis(), ZEND_STRL("channel"), channelObj TSRMLS_CC);
-	zend_update_property(this_ce, getThis(), ZEND_STRL("connection"), PHP_AMQP_READ_OBJ_PROP(amqp_channel_class_entry, channelObj, "connection") TSRMLS_CC);
+	zend_update_property(this_ce, PHP5to8_OBJ_PROP(getThis()), ZEND_STRL("channel"), channelObj TSRMLS_CC);
+	zend_update_property(this_ce, PHP5to8_OBJ_PROP(getThis()), ZEND_STRL("connection"), PHP_AMQP_READ_OBJ_PROP(amqp_channel_class_entry, channelObj, "connection") TSRMLS_CC);
 
 }
 /* }}} */
@@ -122,7 +126,7 @@ static PHP_METHOD(amqp_queue_class, setName)
 	}
 
 	/* Set the queue name */
-	zend_update_property_stringl(this_ce, getThis(), ZEND_STRL("name"), name, name_len TSRMLS_CC);
+	zend_update_property_stringl(this_ce, PHP5to8_OBJ_PROP(getThis()), ZEND_STRL("name"), name, name_len TSRMLS_CC);
 
 	/* BC */
 	RETURN_TRUE;
@@ -137,27 +141,27 @@ static PHP_METHOD(amqp_queue_class, getFlags)
 {
 	PHP5to7_READ_PROP_RV_PARAM_DECL;
 
-	PHP5to7_param_long_type_t flagBitmask = 0;
+	PHP5to7_param_long_type_t flags = 0;
 
 	PHP_AMQP_NOPARAMS();
 
 	if (PHP_AMQP_READ_THIS_PROP_BOOL("passive")) {
-		flagBitmask |= AMQP_PASSIVE;
+		flags |= AMQP_PASSIVE;
 	}
 
 	if (PHP_AMQP_READ_THIS_PROP_BOOL("durable")) {
-		flagBitmask |= AMQP_DURABLE;
+		flags |= AMQP_DURABLE;
 	}
 
 	if (PHP_AMQP_READ_THIS_PROP_BOOL("exclusive")) {
-		flagBitmask |= AMQP_EXCLUSIVE;
+		flags |= AMQP_EXCLUSIVE;
 	}
 
 	if (PHP_AMQP_READ_THIS_PROP_BOOL("auto_delete")) {
-		flagBitmask |= AMQP_AUTODELETE;
+		flags |= AMQP_AUTODELETE;
 	}
 
-	RETURN_LONG(flagBitmask);
+	RETURN_LONG(flags);
 }
 /* }}} */
 
@@ -166,19 +170,20 @@ static PHP_METHOD(amqp_queue_class, getFlags)
 Set the queue parameters */
 static PHP_METHOD(amqp_queue_class, setFlags)
 {
-	PHP5to7_param_long_type_t flagBitmask;
+	PHP5to7_param_long_type_t flags;
+	zend_bool flags_is_null = 1;
 
-	if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "l", &flagBitmask) == FAILURE) {
+	if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "l!", &flags, &flags_is_null) == FAILURE) {
 		return;
 	}
 
 	/* Set the flags based on the bitmask we were given */
-	flagBitmask = flagBitmask ? flagBitmask & PHP_AMQP_QUEUE_FLAGS : flagBitmask;
+	flags = flags ? flags & PHP_AMQP_QUEUE_FLAGS : flags;
 
-	zend_update_property_bool(this_ce, getThis(), ZEND_STRL("passive"), IS_PASSIVE(flagBitmask) TSRMLS_CC);
-	zend_update_property_bool(this_ce, getThis(), ZEND_STRL("durable"), IS_DURABLE(flagBitmask) TSRMLS_CC);
-	zend_update_property_bool(this_ce, getThis(), ZEND_STRL("exclusive"), IS_EXCLUSIVE(flagBitmask) TSRMLS_CC);
-	zend_update_property_bool(this_ce, getThis(), ZEND_STRL("auto_delete"), IS_AUTODELETE(flagBitmask) TSRMLS_CC);
+	zend_update_property_bool(this_ce, PHP5to8_OBJ_PROP(getThis()), ZEND_STRL("passive"), IS_PASSIVE(flags) TSRMLS_CC);
+	zend_update_property_bool(this_ce, PHP5to8_OBJ_PROP(getThis()), ZEND_STRL("durable"), IS_DURABLE(flags) TSRMLS_CC);
+	zend_update_property_bool(this_ce, PHP5to8_OBJ_PROP(getThis()), ZEND_STRL("exclusive"), IS_EXCLUSIVE(flags) TSRMLS_CC);
+	zend_update_property_bool(this_ce, PHP5to8_OBJ_PROP(getThis()), ZEND_STRL("auto_delete"), IS_AUTODELETE(flags) TSRMLS_CC);
 
 	/* BC */
 	RETURN_TRUE;
@@ -250,7 +255,7 @@ static PHP_METHOD(amqp_queue_class, setArguments)
 		return;
 	}
 
-	zend_update_property(this_ce, getThis(), ZEND_STRL("arguments"), zvalArguments TSRMLS_CC);
+	zend_update_property(this_ce, PHP5to8_OBJ_PROP(getThis()), ZEND_STRL("arguments"), zvalArguments TSRMLS_CC);
 
 	RETURN_TRUE;
 }
@@ -342,7 +347,7 @@ static PHP_METHOD(amqp_queue_class, declareQueue)
 
 	/* Set the queue name, in case it is an autogenerated queue name */
 	name = php_amqp_type_amqp_bytes_to_char(r->queue);
-	zend_update_property_string(this_ce, getThis(), ZEND_STRL("name"), name TSRMLS_CC);
+	zend_update_property_string(this_ce, PHP5to8_OBJ_PROP(getThis()), ZEND_STRL("name"), name TSRMLS_CC);
 	efree(name);
 
 	php_amqp_maybe_release_buffers_on_channel(channel_resource->connection_resource, channel_resource);
@@ -525,7 +530,7 @@ static PHP_METHOD(amqp_queue_class, consume)
 	}
 
 	zval *channel_zv = PHP_AMQP_READ_THIS_PROP("channel");
-	zval *consumers = zend_read_property(amqp_channel_class_entry, channel_zv, ZEND_STRL("consumers"), 0 PHP5to7_READ_PROP_RV_PARAM_CC TSRMLS_CC);
+	zval *consumers = zend_read_property(amqp_channel_class_entry, PHP5to8_OBJ_PROP(channel_zv), ZEND_STRL("consumers"), 0 PHP5to7_READ_PROP_RV_PARAM_CC TSRMLS_CC);
 
 	if (IS_ARRAY != Z_TYPE_P(consumers)) {
 		zend_throw_exception(amqp_queue_exception_class_entry, "Invalid channel consumers, forgot to call channel constructor?", 0 TSRMLS_CC);
@@ -594,7 +599,7 @@ static PHP_METHOD(amqp_queue_class, consume)
 		efree(key);
 
 		/* Set the consumer tag name, in case it is an autogenerated consumer tag name */
-		zend_update_property_stringl(this_ce, getThis(), ZEND_STRL("consumer_tag"), (const char *) r->consumer_tag.bytes, (PHP5to7_param_str_len_type_t) r->consumer_tag.len TSRMLS_CC);
+		zend_update_property_stringl(this_ce, PHP5to8_OBJ_PROP(getThis()), ZEND_STRL("consumer_tag"), (const char *) r->consumer_tag.bytes, (PHP5to7_param_str_len_type_t) r->consumer_tag.len TSRMLS_CC);
 	}
 
 	if (!ZEND_FCI_INITIALIZED(fci)) {
@@ -674,7 +679,7 @@ static PHP_METHOD(amqp_queue_class, consume)
 		current_channel_zv = current_channel_resource->parent->this_ptr;
 #endif
 
-		consumers = zend_read_property(amqp_channel_class_entry, PHP5to7_MAYBE_PTR(current_channel_zv), ZEND_STRL("consumers"), 0 PHP5to7_READ_PROP_RV_PARAM_CC TSRMLS_CC);
+		consumers = zend_read_property(amqp_channel_class_entry, PHP5to8_OBJ_PROP(PHP5to7_MAYBE_PTR(current_channel_zv)), ZEND_STRL("consumers"), 0 PHP5to7_READ_PROP_RV_PARAM_CC TSRMLS_CC);
 
 		if (IS_ARRAY != Z_TYPE_P(consumers)) {
 			zend_throw_exception(amqp_queue_exception_class_entry, "Invalid channel consumers, forgot to call channel constructor?", 0 TSRMLS_CC);
@@ -689,8 +694,8 @@ static PHP_METHOD(amqp_queue_class, consume)
 			PHP5to7_zval_t exception PHP5to7_MAYBE_SET_TO_NULL;
 			PHP5to7_MAYBE_INIT(exception);
 			object_init_ex(PHP5to7_MAYBE_PTR(exception), amqp_envelope_exception_class_entry);
-		    zend_update_property_string(zend_exception_get_default(TSRMLS_C), PHP5to7_MAYBE_PTR(exception),  ZEND_STRL("message"), "Orphaned envelope" TSRMLS_CC);
-			zend_update_property(amqp_envelope_exception_class_entry, PHP5to7_MAYBE_PTR(exception), ZEND_STRL("envelope"), PHP5to7_MAYBE_PTR(message) TSRMLS_CC);
+		    zend_update_property_string(zend_exception_get_default(TSRMLS_C), PHP5to8_OBJ_PROP(PHP5to7_MAYBE_PTR(exception)),  ZEND_STRL("message"), "Orphaned envelope" TSRMLS_CC);
+			zend_update_property(amqp_envelope_exception_class_entry, PHP5to8_OBJ_PROP(PHP5to7_MAYBE_PTR(exception)), ZEND_STRL("envelope"), PHP5to7_MAYBE_PTR(message) TSRMLS_CC);
 
 			zend_throw_exception_object(PHP5to7_MAYBE_PTR(exception) TSRMLS_CC);
 
@@ -946,7 +951,7 @@ static PHP_METHOD(amqp_queue_class, cancel)
 	}
 
 	zval *channel_zv = PHP_AMQP_READ_THIS_PROP("channel");
-	zval *consumers = zend_read_property(amqp_channel_class_entry, channel_zv, ZEND_STRL("consumers"), 0 PHP5to7_READ_PROP_RV_PARAM_CC TSRMLS_CC);
+	zval *consumers = zend_read_property(amqp_channel_class_entry, PHP5to8_OBJ_PROP(channel_zv), ZEND_STRL("consumers"), 0 PHP5to7_READ_PROP_RV_PARAM_CC TSRMLS_CC);
 	zend_bool has_consumer_tag = (zend_bool) (IS_STRING == Z_TYPE_P(PHP_AMQP_READ_THIS_PROP("consumer_tag")));
 
 	if (IS_ARRAY != Z_TYPE_P(consumers)) {
@@ -977,8 +982,8 @@ static PHP_METHOD(amqp_queue_class, cancel)
 		return;
 	}
 
-	if (!consumer_tag_len || has_consumer_tag && strcmp(consumer_tag, PHP_AMQP_READ_THIS_PROP_STR("consumer_tag")) != 0) {
-		zend_update_property_null(this_ce, getThis(), ZEND_STRL("consumer_tag") TSRMLS_CC);
+	if (!consumer_tag_len || (has_consumer_tag && strcmp(consumer_tag, PHP_AMQP_READ_THIS_PROP_STR("consumer_tag")) != 0)) {
+		zend_update_property_null(this_ce, PHP5to8_OBJ_PROP(getThis()), ZEND_STRL("consumer_tag") TSRMLS_CC);
 	}
 
     char *key;
